#! /usr/bin/guile -s
!#

;;; Autounit test
;;; Copyright (C) 2002 James Lewismoss
 
;;; This library is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU Library General Public
;;; License as published by the Free Software Foundation; either
;;; version 2 of the License, or (at your option) any later version.
 
;;; This library is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
;;; Library General Public License for more details.
 
;;; You should have received a copy of the GNU Library General Public
;;; License along with this library; if not, write to the
;;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;;; Boston, MA 02111-1307, USA.

(debug-enable 'backtrace)
(debug-enable 'debug)

(use-modules (autounit backend)
             (autounit suite))

(define failures 0)
(define tests 0)
(define (success)
  (set! tests (1+ tests)))
(define (failure)
  (set! failures (1+ failures))
  (set! tests (1+ tests)))

(catch #t
       (lambda ()
         au:failure-exception
         (success))
       (lambda (key . args)
         (failure)))

(catch #t
       (lambda ()
         au:autounit-misuse
         (success))
       (lambda (key . args)
         (failure)))


(catch au:autounit-misuse
       (lambda ()
         (au:declare 'foobar #t #f)
         (failure))
       (lambda (key . args)
         (success)))

(catch au:failure-exception
       (lambda ()
         (au:declare #f #f #f)
         (failure))
       (lambda (key . args)
         (success)))

(define test-suite (au:suite-make "Test Suite"))
(catch au:failure-exception
       (lambda ()
         (au:declare test-suite #f #f)
         (failure))
       (lambda (key . args)
         (success)))
(let ((messages (au:suite-get-messages test-suite)))
  (if (not (= (length messages) 1))
      (failure)
      (success)))

(catch au:failure-exception
       (lambda ()
         (au:declare #t #f #f)
         (failure))
       (lambda (key . args)
         (success)))
(let ((messages (au:suite-get-messages (au:get-default-suite))))
  (if (not (= (length messages) 1))
      (failure)
      (success)))


(if (> failures 0)
    (begin
      (display "FAILURE: ") (display failures)
      (display " out of ") (display tests) (newline)
      (exit 1))
    (begin
      (display "Ran ")(display tests)(display " successfully")(newline)
      (exit 0)))


