#! /usr/bin/guile -s
!#

;;; Autounit test
;;; Copyright (C) 2002 James Lewismoss
 
;;; This library is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU Library General Public
;;; License as published by the Free Software Foundation; either
;;; version 2 of the License, or (at your option) any later version.
 
;;; This library is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
;;; Library General Public License for more details.
 
;;; You should have received a copy of the GNU Library General Public
;;; License along with this library; if not, write to the
;;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;;; Boston, MA 02111-1307, USA.

(debug-enable 'backtrace)
(debug-enable 'debug)

(use-modules (autounit test)
             (autounit suite))

(define failures 0)
(define tests 0)
(define (success)
  (set! tests (1+ tests)))
(define (failure)
  (set! failures (1+ failures))
  (set! tests (1+ tests)))

(define test-case (au:test-make
                   "test-case 1"
                   (list (lambda (suite data) (success)))))
(if (au:is-test? test-case)
    (success)
    (failure))
(if (equal? (au:test-get-name test-case) "test-case 1")
    (success)
    (failure))
(au:test-run #f test-case)

(define test-case2 (au:test-make
                    "test-case 2"
                    (list (lambda (suite data) (success)))
                    (lambda (data) #t)
                    (lambda (data) #t)))
(if (au:is-test? test-case2)
    (success)
    (failure))
(if (equal? (au:test-get-name test-case2) "test-case 2")
    (success)
    (failure))
(au:test-run #f test-case2)


(au:test-run #f
 (au:test-make "test case 2"
               (list (lambda (suite data)
                       (if (equal? (hash-ref data 'foobar) "FOOBAR")
                           (success)
                           (failure))))
               (lambda (data) (hash-set! data 'foobar "FOOBAR"))))

(letrec ((somevar #f)
         (tests (list (lambda (suite data)
                        (if (equal? somevar "FOOBAR")
                            (success)
                            (failure)))))
         (setup (lambda (data) (set! somevar "FOOBAR")))
         (teardown (lambda (data) (set! somevar "BLEH"))))
  (if (not somevar)
      (success)
      (failure))
  (au:test-run #f
   (au:test-make "test case 3" tests setup teardown))
  (if (equal? somevar "BLEH")
      (success)
      (failure)))

(if (> failures 0)
    (begin
      (display "FAILURE: ") (display failures)
      (display " out of ") (display tests) (newline)
      (exit 1))
    (begin
      (display "Ran ")(display tests)(display " successfully")(newline)
      (exit 0)))

